import { defineComponent, ref, computed, resolveComponent, openBlock, createElementBlock, Fragment, createVNode, unref, withCtx, createElementVNode, normalizeClass, createTextVNode, isRef } from "vue";
import { o as EventBus, I as InlineSvg, a0 as svgPath, a1 as __serializeForClipboard } from "./kit-9e2091b1.js";
import { u as useForm, a as useField, c as create$6, E as ErrorMessage } from "./vee-validate.esm-94488b85.js";
import "element-plus";
const _hoisted_1 = ["disabled"];
const _hoisted_2 = { class: "pb-3" };
const _hoisted_3 = { class: "flex items-center" };
const _hoisted_4 = /* @__PURE__ */ createElementVNode("label", { class: "fw600 fs15 w-50px" }, "文本", -1);
const _hoisted_5 = { class: "mt-5 flex items-center" };
const _hoisted_6 = /* @__PURE__ */ createElementVNode("label", { class: "fw600 fs15 w-50px" }, "链接", -1);
const __default__ = defineComponent({
  name: "tiptap-menus-link"
});
const _sfc_main = /* @__PURE__ */ defineComponent({
  ...__default__,
  props: {
    editor: null
  },
  setup(__props) {
    const props = __props;
    const serializeForClipboard = __serializeForClipboard;
    const { handleSubmit, isSubmitting, resetForm } = useForm({
      initialValues: {
        text: "",
        href: ""
      }
    });
    const { value: text } = useField("text", create$6());
    const { value: href } = useField("href", create$6().required("外链地址不能为空！").url("请输入有效链接！"));
    const isEdit = ref(false);
    const dialogVisible = ref(false);
    const isLinkActive = computed(() => {
      var _a;
      return (_a = props.editor) == null ? void 0 : _a.isActive.apply(props.editor, ["link"]);
    });
    const isTitleActive = computed(() => {
      var _a;
      return (_a = props.editor) == null ? void 0 : _a.isActive.apply(props.editor, ["title"]);
    });
    new EventBus().on("edit-link", () => {
      const view = props.editor.view;
      const slice = view.state.selection.content();
      const { text: txt } = serializeForClipboard(view, slice);
      const { href: url } = props.editor.getAttributes("link");
      text.value = txt;
      href.value = url;
      isEdit.value = true;
      dialogVisible.value = true;
    });
    const link = () => {
      if (isLinkActive.value) {
        props.editor.chain().focus().unsetLink().run();
      } else {
        const view = props.editor.view;
        const slice = view.state.selection.content();
        const { text: txt } = serializeForClipboard(view, slice);
        text.value = txt ?? "";
        dialogVisible.value = true;
      }
    };
    const onSubmit = handleSubmit((values) => {
      if (!values.text) {
        values.text = values.href;
      }
      const { view, state } = props.editor;
      const schema = view.state.schema;
      const node = schema.text(values.text, [schema.marks.link.create({ href: values.href })]);
      view.dispatch(view.state.tr.deleteRange(state.selection.from, state.selection.to));
      view.dispatch(view.state.tr.insert(state.selection.from, node));
      view.dispatch(view.state.tr.scrollIntoView());
      dialogVisible.value = false;
    });
    const onReset = () => {
      var _a;
      (_a = props.editor) == null ? void 0 : _a.chain().focus();
      isEdit.value = false;
      resetForm();
    };
    return (_ctx, _cache) => {
      const _component_el_tooltip = resolveComponent("el-tooltip");
      const _component_el_input = resolveComponent("el-input");
      const _component_el_button = resolveComponent("el-button");
      const _component_el_dialog = resolveComponent("el-dialog");
      return openBlock(), createElementBlock(Fragment, null, [
        createVNode(_component_el_tooltip, {
          content: `${unref(isLinkActive) ? "去除" : "插入"}链接`,
          effect: "dark",
          placement: "top",
          enterable: false,
          "hide-after": 0,
          transition: "none"
        }, {
          default: withCtx(() => [
            createElementVNode("button", {
              class: normalizeClass(["tiptap-button", {
                "bg-light-dark": unref(isLinkActive),
                "bg-hover-secondary": !unref(isTitleActive),
                "text-gray-500": unref(isTitleActive)
              }]),
              disabled: unref(isTitleActive),
              onClick: link
            }, [
              createVNode(unref(InlineSvg), {
                class: "w-16px h-16px",
                src: unref(svgPath)
              }, null, 8, ["src"])
            ], 10, _hoisted_1)
          ]),
          _: 1
        }, 8, ["content"]),
        createVNode(_component_el_dialog, {
          modelValue: dialogVisible.value,
          "onUpdate:modelValue": _cache[3] || (_cache[3] = ($event) => dialogVisible.value = $event),
          title: `${isEdit.value ? "编辑" : "插入"}链接`,
          width: "448px",
          "align-center": "",
          onClosed: onReset
        }, {
          footer: withCtx(() => [
            createVNode(_component_el_button, {
              onClick: _cache[2] || (_cache[2] = ($event) => dialogVisible.value = false)
            }, {
              default: withCtx(() => [
                createTextVNode("取 消")
              ]),
              _: 1
            }),
            createVNode(_component_el_button, {
              disabled: unref(isSubmitting),
              loading: unref(isSubmitting),
              type: "primary",
              onClick: unref(onSubmit)
            }, {
              default: withCtx(() => [
                createTextVNode(" 确 认 ")
              ]),
              _: 1
            }, 8, ["disabled", "loading", "onClick"])
          ]),
          default: withCtx(() => [
            createElementVNode("div", _hoisted_2, [
              createElementVNode("div", _hoisted_3, [
                _hoisted_4,
                createVNode(_component_el_input, {
                  class: "flex-1",
                  size: "large",
                  modelValue: unref(text),
                  "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => isRef(text) ? text.value = $event : null),
                  placeholder: "请输入文本"
                }, null, 8, ["modelValue"])
              ]),
              createElementVNode("div", _hoisted_5, [
                _hoisted_6,
                createVNode(_component_el_input, {
                  class: "flex-1",
                  size: "large",
                  modelValue: unref(href),
                  "onUpdate:modelValue": _cache[1] || (_cache[1] = ($event) => isRef(href) ? href.value = $event : null),
                  placeholder: "请输入外链地址"
                }, null, 8, ["modelValue"])
              ]),
              createVNode(unref(ErrorMessage), {
                class: "mt-2 ml-50px text-danger",
                name: "href",
                as: "div"
              })
            ])
          ]),
          _: 1
        }, 8, ["modelValue", "title"])
      ], 64);
    };
  }
});
export {
  _sfc_main as default
};
